OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendari",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Recurs",
    "Room" : "Sala",
    "Unknown" : "Desconegut",
    "Required" : "Requerit",
    "Optional" : "Opcional",
    "Does not attend" : "No assistir",
    "Please create a calendar first." : "Si us plau, creeu un calendari primer",
    "New event" : "Esdeveniment nou",
    "Attendees" : "Assistents",
    "Reminders" : "Recordatoris",
    "Repeating" : "Repetició",
    "When shared show full event" : "Mostrar l'esdeveniment sencer al compartir",
    "When shared show only busy" : "Mostra només ocupat al compartir",
    "When shared hide this event" : "Ocular aquest esdeveniment al compartir",
    "Cancelled" : "S'ha cancel·lat",
    "Please add a title!" : "Si us plau, afegiu un títol!",
    "Please select a calendar!" : "Si us plau, seleccioneu un calendari!",
    "Global" : "Global",
    "None" : "Cap",
    "Every day" : "Cada dia",
    "Every week" : "Cada setmana",
    "Every month" : "Cada mes",
    "Every year" : "Cada any",
    "never" : "mai",
    "after" : "després de",
    "At time of event" : "En el moment de l'esdeveniment",
    "5 minutes before" : "5 minuts abans",
    "10 minutes before" : "10 minuts abans",
    "15 minutes before" : "15 minuts abans",
    "30 minutes before" : "30 minuts abans",
    "1 hour before" : "1 hora abans",
    "2 hours before" : "2 hores abans",
    "Custom" : "Personalitza...",
    "Audio" : "Audio",
    "E Mail" : "Correu",
    "Pop up" : "Finestra emergent",
    "sec" : "seg",
    "min" : "min",
    "hours" : "hores",
    "days" : "dies",
    "week" : "setmana",
    "before" : "abans",
    "start" : "comença",
    "end" : "final",
    "Week {number} of {year}" : "Setmana {number} de {year}",
    "Successfully imported" : "S'ha importat correctament",
    "Partially imported, 1 failure" : "Parcialment importat, 1 error",
    "Partially imported, {n} failures" : "Parcialment importat, {n} errors",
    "Audio alarm" : "So d'alarma",
    "Pop-up" : "Finestra emergent",
    "E-Mail" : "Correu",
    "{type} {time} before the event starts" : "{type} {time} abans que comenci l'esdeveniment",
    "{type} {time} before the event ends" : "{type} {time} abans que finalitzi l'esdeveniment",
    "{type} {time} after the event starts" : "{type} {time} després que comenci l'esdeveniment",
    "{type} {time} after the event ends" : "{type} {time} després que finalitzi l'esdeveniment",
    "{type} at the event's start" : "{type} al principi de l'esdeveniment",
    "{type} at the event's end" : "{type} al final de l'esdeveniment",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartit per {owner}",
    "Title of the Event" : "Títol de l'esdeveniment",
    "starts" : "comença",
    "ends" : "finalitza",
    "All day Event" : "Esdeveniment de tot el dia",
    "Delete" : "Esborra",
    "Cancel" : "Cancel·la",
    "More ..." : "Més",
    "Create" : "Crea",
    "Update" : "Actualitza",
    "Close" : "tanca",
    "Location" : "Ubicació",
    "Description" : "Descripció",
    "Export" : "Exporta",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa d'un error (bug) de \"upstrem\", el calendari no suporta la funció \"asset pipeline\"",
    "Day" : "Dia",
    "Week" : "Setmana",
    "Month" : "Mes",
    "Today" : "Avui",
    "Share Calendar" : "Comparteix el calendari",
    "Shared" : "Compartit",
    "More" : "Més",
    "Edit" : "Edita",
    "Link" : "Enllaç",
    "Download" : "Descàrrega",
    "can edit" : "pot editar",
    "group" : "grup",
    "New Calendar" : "Calendari nou",
    "Subscriptions" : "Subscripcions",
    "New Subscription" : "Nova subscripció",
    "Url" : "Url",
    "Edit event" : "Edita l'esdeveniment",
    "Delete Event" : "Esborra l'esdeveniment",
    "Save Event" : "Desa l'esdeveniment",
    "Time" : "Hora",
    "Type" : "Tipus",
    "Relative" : "Relatiu",
    "Absolute" : "Absolut",
    "Repeat" : "Repeteix",
    "times every" : "vegades cada",
    "Add" : "Afegeix",
    "E-Mail address of attendee" : "Adreça de correu electrònic de l'assistent",
    "Please add your email address in the personal settings in order to add attendees." : "Si us plau, introduïu la vostra adreça de correu electrònic a la configuració del compte per poder afegir assistents",
    "from" : "des de",
    "to" : "a",
    "New calendar" : "Calendari nou",
    "Settings" : "configuració",
    "Primary CalDAV address" : "Adreça primària de caldav",
    "iOS/OS X CalDAV address" : "Adreça CalDAV per IOS/OS X"
},
"nplurals=2; plural=(n != 1);");
